descope.tokenizer
=================

.. automodule:: descope.tokenizer
   :members:
   :undoc-members:
   :show-inheritance:
   :exclude-members:
        _filter_perturbations,
        _merge_list_of_dicts